==> efront-3.5.0.b4.tbz: www/efront/www/editor/tiny_mce/plugins/mathtype/mathtype.php <==
<?php

session_cache_limiter('none');
session_start();

$path = "../../../../../libraries/";

/**   .*/
include_once $path."configuration.php";

eF_printHeader();
echo "<p>"._MATHTYPEHELP."</p>";
?>
<table align="center" width=80% border="3" cellpadding="5">

<tr>
<td>\`x^2+y_1+z_12^34\`</td>
<td>`x^2+y_1+z_12^34`</td>

</tr>
<tr>
<td>\`sin^-1(x)\`</td>
<td>`sin^-1(x)`</td>
</tr>
<tr>

<td>\`d/dxf(x)=lim_(h->0)(f(x+h)-f(x))/h\`</td>
<td>`d/dxf(x)=lim_(h->0)(f(x+h)-f(x))/h`</td>

</tr>
<tr>
<td>\$\frac{d}{dx}f(x)=\lim_{h\to 0}\frac{f(x+h)-f(x)}{h}\$</td>
<td>$\frac{d}{dx}f(x)=\lim_{h\to 0}\frac{f(x+h)-f(x)}{h}$</td>

</tr>
<tr>
<td>\`f(x)=sum_(n=0)^oo(f^((n))(a))/(n!)(x-a)^n\`</td>
<td>`f(x)=sum_(n=0)^oo(f^((n))(a))/(n!)(x-a)^n`</td>

</tr>
<tr>
<td>\$f(x)=\sum_{n=0}^\infty\frac{f^{(n)}(a)}{n!}(x-a)^n\$</td>
<td>$f(x)=\sum_{n=0}^\infty\frac{f^{(n)}(a)}{n!}(x-a)^n$</td>
</tr>
<tr>
<td>\`int_0^1f(x)dx\`</td>
<td>`int_0^1f(x)dx`</td>
</tr>
<tr>
<td>\`[[a,b],[c,d]]((n),(k))\`</td>
<td>`[[a,b],[c,d]]((n),(k))`</td>

</tr>
<tr>
<td>\`x/x={(1,if x!=0),(text{undefined},if x=0):}\`</td>
<td>`x/x={(1,if x!=0),(text{undefined},if x=0):}`</td>
</tr>
<tr>
<td>\`a//b\`</td>
<td>`a//b`</td>

</tr>
<tr>
<td>\`(a/b)/(c/d)\`</td>
<td>`(a/b)/(c/d)`</td>
</tr>

<tr>
<td>\`a/b/c/d\`</td>
<td>`a/b/c/d`</td>

</tr>
<tr>
<td>\`((a*b))/c\`</td>
<td>`((a*b))/c`</td>

</tr>
<tr>
<td>\`sqrtsqrtroot3x\`</td>
<td>`sqrtsqrtroot3x`</td>
</tr>

<tr>
<td>\`(:a,b:) and {:(x,y),(u,v):}\`</td>
<td>`(:a,b:) and {:(x,y),(u,v):}`</td>
</tr>

<tr>
<td>\`(a,b]={x in RR : a < x <= b}\`</td>
<td>`(a,b]={x in RR : a < x <= b}`</td>
</tr>

<tr>
<td>\`abc-123.45^-1.1\`</td>
<td>`abc-123.45^-1.1`</td>
</tr>

<tr>
<td>\`hat(ab) bar(xy) ulA vec v dotx ddot y\`</td>
<td>`hat(ab) bar(xy) ulA vec v dotx ddot y`</td>
</tr>

<tr>
<td>\`bb{AB3}.bbb(AB].cc(AB).fr{AB}.tt[AB].sf(AB)\`</td>
<td>`bb{AB3}.bbb(AB].cc(AB).fr{AB}.tt[AB].sf(AB)`</td>
</tr>

<tr>
<td>\`stackrel"def"= or \stackrel{\Delta}{=}" "("or ":=)\`</td>
<td>`stackrel"def"= or \stackrel{\Delta}{=}" "("or ":=)`</td>
</tr>

<tr>
<td>\`{::}_(\ 92)^238U\`</td>
<td>`{::}_(\ 92)^238U`</td>
</tr>
</table>

==> efront-3.5.2.tbz: www/efront/www/editor/tiny_mce/plugins/mathtype/mathtype.php <==
<?php

session_cache_limiter('none');
session_start();

$path = "../../../../../libraries/";

/**   .*/
include_once $path."configuration.php";
eF_printHeader();
echo ' <script language = "JavaScript" type = "text/javascript" src = "../../../../js/ASCIIMathML.php"> </script>';
echo "<p>"._MATHTYPEHELP1.""._MATHTYPEHELP2."</p>";
?>
<table align="center" width=80% border="3" cellpadding="5">

<tr>
<td>\`x^2+y_1+z_12^34\`</td>
<td>`x^2+y_1+z_12^34`</td>

</tr>
<tr>
<td>\`sin^-1(x)\`</td>
<td>`sin^-1(x)`</td>
</tr>
<tr>

<td>\`d/dxf(x)=lim_(h->0)(f(x+h)-f(x))/h\`</td>
<td>`d/dxf(x)=lim_(h->0)(f(x+h)-f(x))/h`</td>

</tr>
<tr>
<td>\$\frac{d}{dx}f(x)=\lim_{h\to 0}\frac{f(x+h)-f(x)}{h}\$</td>
<td>$\frac{d}{dx}f(x)=\lim_{h\to 0}\frac{f(x+h)-f(x)}{h}$</td>

</tr>
<tr>
<td>\`f(x)=sum_(n=0)^oo(f^((n))(a))/(n!)(x-a)^n\`</td>
<td>`f(x)=sum_(n=0)^oo(f^((n))(a))/(n!)(x-a)^n`</td>

</tr>
<tr>
<td>\$f(x)=\sum_{n=0}^\infty\frac{f^{(n)}(a)}{n!}(x-a)^n\$</td>
<td>$f(x)=\sum_{n=0}^\infty\frac{f^{(n)}(a)}{n!}(x-a)^n$</td>
</tr>
<tr>
<td>\`int_0^1f(x)dx\`</td>
<td>`int_0^1f(x)dx`</td>
</tr>
<tr>
<td>\`[[a,b],[c,d]]((n),(k))\`</td>
<td>`[[a,b],[c,d]]((n),(k))`</td>

</tr>
<tr>
<td>\`x/x={(1,if x!=0),(text{undefined},if x=0):}\`</td>
<td>`x/x={(1,if x!=0),(text{undefined},if x=0):}`</td>
</tr>
<tr>
<td>\`a//b\`</td>
<td>`a//b`</td>

</tr>
<tr>
<td>\`(a/b)/(c/d)\`</td>
<td>`(a/b)/(c/d)`</td>
</tr>

<tr>
<td>\`a/b/c/d\`</td>
<td>`a/b/c/d`</td>

</tr>
<tr>
<td>\`((a*b))/c\`</td>
<td>`((a*b))/c`</td>

</tr>
<tr>
<td>\`sqrtsqrtroot3x\`</td>
<td>`sqrtsqrtroot3x`</td>
</tr>

<tr>
<td>\`(:a,b:) and {:(x,y),(u,v):}\`</td>
<td>`(:a,b:) and {:(x,y),(u,v):}`</td>
</tr>

<tr>
<td>\`(a,b]={x in RR : a < x <= b}\`</td>
<td>`(a,b]={x in RR : a < x <= b}`</td>
</tr>

<tr>
<td>\`abc-123.45^-1.1\`</td>
<td>`abc-123.45^-1.1`</td>
</tr>

<tr>
<td>\`hat(ab) bar(xy) ulA vec v dotx ddot y\`</td>
<td>`hat(ab) bar(xy) ulA vec v dotx ddot y`</td>
</tr>

<tr>
<td>\`bb{AB3}.bbb(AB].cc(AB).fr{AB}.tt[AB].sf(AB)\`</td>
<td>`bb{AB3}.bbb(AB].cc(AB).fr{AB}.tt[AB].sf(AB)`</td>
</tr>

<tr>
<td>\`stackrel"def"= or \stackrel{\Delta}{=}" "("or ":=)\`</td>
<td>`stackrel"def"= or \stackrel{\Delta}{=}" "("or ":=)`</td>
</tr>

<tr>
<td>\`{::}_(\ 92)^238U\`</td>
<td>`{::}_(\ 92)^238U`</td>
</tr>
</table>
